FHanalyze package
=================

The FHanalyze package analyzes the readings that were stored into the Raspberry Pi's mongo db
by calls to the `FHmonitor package <https://fhmonitor.readthedocs.io/en/latest/FHmonitor.html#intro>`_.

Analyze class
~~~~~~~~~~~~~
The analyze class takes the power readings from the mongodb store and provides methods to analyze
the readings.

.. automodule:: FHanalyze.analyze
   :members:
   :undoc-members:
